#
from enigma import *
from Screens.Screen import Screen
from Screens.MessageBox import MessageBox
from Screens.InputBox import InputBox
from Screens.ChoiceBox import ChoiceBox
from Components.ActionMap import ActionMap, NumberActionMap
from Components.ScrollLabel import ScrollLabel
from Components.GUIComponent import *
from Components.MenuList import MenuList
from Components.Input import Input
from Screens.Console import Console
from Plugins.Plugin import PluginDescriptor
from Screens.ImageWizard import ImageWizard
from Plugins.Plugin import PluginDescriptor

import os

###############################################################################

er_path = "/usr/lib/enigma2/python/Plugins/Extensions/DM7025remote"
er_script = "/usr/lib/enigma2/python/Plugins/Extensions/DM7025remote/er.sh"
er_readme = "/usr/lib/enigma2/python/Plugins/Extensions/DM7025remote/readme.txt"

###############################################################################
# versionstring
###############################################################################
er_pluginversion = "V3.1"

###############################################################################
def main(session,**kwargs):
    try:    
     	session.open(Er)
    except:
        print "[RC] Pluginexecution failed"
###############################################################################
def autostart(reason,**kwargs):
    if reason == 0:
        print "[RC] no autostart"
###############################################################################
def Plugins(**kwargs):
    return PluginDescriptor(
        name="DM 7025 Remote Control", 
        description="plugin for Remote Control", 
        where = PluginDescriptor.WHERE_PLUGINMENU,
        fnc = main
        )
###############################################################################
###############################################################################
class Er(Screen):
    skin = """
        <screen position="100,100" size="500,400" title="Remote Control Menu" >
            <widget name="menu" position="10,10" size="490,390" scrollbarMode="showOnDemand" />
        </screen>"""
        
    def __init__(self, session, args = 0):
        self.skin = Er.skin
        self.session = session
        Screen.__init__(self, session)
        self.menu = args
        list = []
        list.append((_("info if Mediaserver is running"), "info"))        
        list.append((_("restart options"), "restartwizzard"))
        list.append((_("install options (enable once before using !)"), "installwizzard"))
        list.append((_("help"), "help"))        
        list.append((_("man"), "man"))        
        list.append((_("about"), "about"))        
        self["menu"] = MenuList(list)
        self["actions"] = ActionMap(["WizardActions", "DirectionActions"],{"ok": self.go,"back": self.close,}, -1)
        
    def go(self):
        returnValue = self["menu"].l.getCurrentSelection()[1]
        if returnValue is not None:
           if returnValue is "info":
             self.session.open(Console,_("showing RC Info"),["%s info" % er_script])
           elif returnValue is "restartwizzard":
               RestartWizzard(self.session)
           elif returnValue is "installwizzard":
               InstallWizzard(self.session)
           elif returnValue is "man":
             self.session.open(Console,_("man shows readme.txt of RC"),["cat %s" % er_readme])
           elif returnValue is "help":
             self.session.open(Console,_("short help on RC commands"),["%s" % er_script])
           elif returnValue is "about":
             self.session.open(MessageBox,_("Remote Control Enigma2 Plugin %s\n\nRC tool by thowi\n\nMediaserver by 3c5x9\n\nEnjoy Remote Controlling DM 7025 !" % er_pluginversion), MessageBox.TYPE_INFO)


###############################################################################
###############################################################################


class InstallWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForInstall()
        
    def askForInstall(self):
            self.session.openWithCallback(self.askForCommand,ChoiceBox,_("select Er install command to be executed"),self.getCommandList())

    def askForCommand(self,source):
        if source is None:
            self.skipInstall("no command passed, skipping install")
        else:
            self.source = source [1]
            self.session.openWithCallback(self.installCommand,MessageBox,_("are you sure to install ER with %s" % self.source), MessageBox.TYPE_YESNO)
            
    def installCommand(self,answer):
        if answer is None:
            self.skipInstall("answer is None")
        if answer is False:
            self.skipInstall("you were not confirming")
        else:
            self.session.open(Console,_("executing install command"),["%s %s" % (er_script,self.source)])
            
    def skipInstall(self,reason):
        self.session.open(MessageBox,_("install was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
    def getCommandList(self):
        images = []
        images.append((_("enable  Mediaserver daemon"),"enable"))
        images.append((_("disable Mediaserver daemon"),"disable"))
        return images
        
###############################################################################
###############################################################################

class RestartWizzard(Screen):
    def __init__(self, session):
        self.session = session
        self.askForRestart()
        
    def askForRestart(self):
            self.session.openWithCallback(self.askForCommand,ChoiceBox,_("select restart command to be executed"),self.getCommandList())

    def askForCommand(self,source):
        if source is None:
            self.skipRestart("no command passed, skipping restart")
        else:
            self.source = source [1]
            self.session.openWithCallback(self.restartCommand,MessageBox,_("are you sure to %s" % self.source), MessageBox.TYPE_YESNO)
            
    def restartCommand(self,answer):
        if answer is None:
            self.skipRestart("answer is None")
        if answer is False:
            self.skipRestart("you were not confirming")
        else:
            title = "executing command on Dreambox"
            cmd = "%s %s"  % (er_script,self.source)
            self.session.open(Console,_(title),[cmd])
            
    def skipRestart(self,reason):
        self.session.open(MessageBox,_("restart was canceled, because %s" % reason), MessageBox.TYPE_WARNING)
        
    def getCommandList(self):
        images = []
        images.append((_("info if Mediaserver dameon is running"),"info"))
        images.append((_("start   Mediaserver daemon"),"start"))
        images.append((_("stop    Mediaserver daemon"),"stop"))
        images.append((_("restart Mediaserver dameon"),"restart"))
        images.append((_("reboot  Dreambox"),"reboot"))
        images.append((_("halt    Dreambox"),"halt"))
        images.append((_("restart Enigma on Dreambox"),"kill"))
        return images

###############################################################################
###############################################################################
